@@ -31,7 +31,7 @@ import datetime
 import time
 import collections
 
-VERSION = (0, 3, 2)
+VERSION = (0, 3, 3)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -309,6 +309,8 @@ def escape_parameter(v):
         return str(v)
     elif t == decimal.Decimal:
         return "'" + str(v) + "'"
+    elif t == list or t == tuple:
+        return u'{' + u','.join([escape_parameter(e) for e in v]) + u'}'
     else:
         return "'" + str(v) + "'"
 
